@@ -33,18 +33,19 @@ public:
 
 public slots:
     void accept();
-    void license();
+    void toggleTitle();
 
 private:
     QFrame*      mLine;
     QPushButton* mButtonLicense;
     QPushButton* mButtonOk;
     QLabel*      mTitlePixmapLabel;
+    QLabel*      mTitleLicenseLabel;
     QHBoxLayout* mButtonLayout;
     QVBoxLayout* mLayout;
     QPixmap      mTitlePixmap;
     QString      mVersionText;
-    bool         mTitleShown;
+    bool         mTitlePixmapShown;
 };
 
 #endif
